Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins')
-rw-r--r--extraplugins/EFFBD/org.eclipse.papyrus.effbd/plugin.properties2
-rw-r--r--extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/ConfigureFunction.java2
-rw-r--r--extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/CreateEFFBModelCommand.java8
-rw-r--r--extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/factory/IBasicViewFactory.java2
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation.config/src/org/eclipse/papyrus/eastadl/nattable/allocation/config/handler/CreateFunctionAllocationHandler.java78
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/OSGI-INF/l10n/bundle.properties4
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_Eastadl_Allocation_new.png (renamed from extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_SysML_Allocation_new.png)bin311 -> 311 bytes
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/plugin.xml126
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.menu/OSGI-INF/l10n/bundle.properties6
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/elements/EastadlElementTypes.java26
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/menu/AbstractCreateEastadlChildMenu.java34
-rw-r--r--extraplugins/req/org.eclipse.papyrus.req.reqif/META-INF/MANIFEST.MF1
-rw-r--r--extraplugins/req/org.eclipse.papyrus.req.reqif/src/org/eclipse/papyrus/req/reqif/integration/transformation/ReqIFImporterServiceEdit.java285
-rw-r--r--extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlModelWizard.java149
-rw-r--r--extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlProjectWizard.java144
15 files changed, 430 insertions, 437 deletions
diff --git a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/plugin.properties b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/plugin.properties
index 9c2bc45485c..05a3d55bbb2 100644
--- a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/plugin.properties
+++ b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/plugin.properties
@@ -12,5 +12,5 @@
#
########################################################################################
providerName=Eclipse Modeling Project
-pluginName=SysML for EFFBD
+pluginName=EFFBD
diff --git a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/ConfigureFunction.java b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/ConfigureFunction.java
index 37ed2825299..2ca013cb019 100644
--- a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/ConfigureFunction.java
+++ b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/ConfigureFunction.java
@@ -37,7 +37,7 @@ public class ConfigureFunction extends RecordingCommand {
}
/**
- * get new name of Papyrus SysML requirement
+ * get new ID Function
*
* @param owner
* the package that will contain requirement
diff --git a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/factory/IBasicViewFactory.java b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/factory/IBasicViewFactory.java
index aae79ecdf76..2c28523b2f6 100644
--- a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/factory/IBasicViewFactory.java
+++ b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/factory/IBasicViewFactory.java
@@ -28,7 +28,7 @@ public interface IBasicViewFactory extends ViewFactory {
* Create the the view, a element that represents the serialization of a figure inside the GMF framework
*
* @param domainElement
- * in our case this a SysML element
+ * in our case this a Effbd element
* @param containerView
* the container of the created view
* @param semanticHint
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation.config/src/org/eclipse/papyrus/eastadl/nattable/allocation/config/handler/CreateFunctionAllocationHandler.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation.config/src/org/eclipse/papyrus/eastadl/nattable/allocation/config/handler/CreateFunctionAllocationHandler.java
index f1ebd03f936..231cff2734b 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation.config/src/org/eclipse/papyrus/eastadl/nattable/allocation/config/handler/CreateFunctionAllocationHandler.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation.config/src/org/eclipse/papyrus/eastadl/nattable/allocation/config/handler/CreateFunctionAllocationHandler.java
@@ -1,40 +1,40 @@
-/**
- *
- */
-package org.eclipse.papyrus.eastadl.nattable.allocation.config.handler;
-
-import org.eclipse.emf.common.command.Command;
-import org.eclipse.gmf.runtime.emf.type.core.IElementType;
-import org.eclipse.papyrus.eastadl.nattable.menu.handlers.FunctionAllocationHandler;
-import org.eclipse.papyrus.infra.nattable.manager.table.INattableModelManager;
-import org.eclipse.papyrus.infra.nattable.utils.INattableModelManagerUtils;
-
-public class CreateFunctionAllocationHandler extends FunctionAllocationHandler {
-
- /**
- * the id used for the Papyrus SysML Allocation Table
- */
- public static final String TABLE_ALLOCATION_TYPE = "EAST-ADLFunctionAllocationTable"; //$NON-NLS-1$
-
- /**
- *
- * @see org.eclipse.papyrus.sysml.nattable.menu.handlers.AbstractSysmlNattableCreateCommandHandler#setEnabled(java.lang.Object)
- *
- * @param evaluationContext
- */
- @Override
- public void setEnabled(Object evaluationContext) {
- Command command = getCommand();
- boolean isEnabled = command.canExecute();
- INattableModelManager tableManager = INattableModelManagerUtils.getTableManagerFromWorkbenchPart(getActiveWorkbenchPart());
- isEnabled = isEnabled && tableManager.getTable().getTableConfiguration().getType().equals(TABLE_ALLOCATION_TYPE);
- if (isEnabled) {
- IElementType newElementType = getElementTypeToCreate();
- String id = newElementType.getId();
- isEnabled = tableManager.canCreateRowElement(id);
- }
- setBaseEnabled(isEnabled);
-
- }
-
+/**
+ *
+ */
+package org.eclipse.papyrus.eastadl.nattable.allocation.config.handler;
+
+import org.eclipse.emf.common.command.Command;
+import org.eclipse.gmf.runtime.emf.type.core.IElementType;
+import org.eclipse.papyrus.eastadl.nattable.menu.handlers.FunctionAllocationHandler;
+import org.eclipse.papyrus.infra.nattable.manager.table.INattableModelManager;
+import org.eclipse.papyrus.infra.nattable.utils.INattableModelManagerUtils;
+
+public class CreateFunctionAllocationHandler extends FunctionAllocationHandler {
+
+ /**
+ * the id used for the Papyrus Eastadl Allocation Table
+ */
+ public static final String TABLE_ALLOCATION_TYPE = "EAST-ADLFunctionAllocationTable"; //$NON-NLS-1$
+
+ /**
+ *
+ *
+ *
+ * @param evaluationContext
+ */
+ @Override
+ public void setEnabled(Object evaluationContext) {
+ Command command = getCommand();
+ boolean isEnabled = command.canExecute();
+ INattableModelManager tableManager = INattableModelManagerUtils.getTableManagerFromWorkbenchPart(getActiveWorkbenchPart());
+ isEnabled = isEnabled && tableManager.getTable().getTableConfiguration().getType().equals(TABLE_ALLOCATION_TYPE);
+ if (isEnabled) {
+ IElementType newElementType = getElementTypeToCreate();
+ String id = newElementType.getId();
+ isEnabled = tableManager.canCreateRowElement(id);
+ }
+ setBaseEnabled(isEnabled);
+
+ }
+
} \ No newline at end of file
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/OSGI-INF/l10n/bundle.properties b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/OSGI-INF/l10n/bundle.properties
index 0c50729b30a..d3171fb0616 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/OSGI-INF/l10n/bundle.properties
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/OSGI-INF/l10n/bundle.properties
@@ -1,3 +1,3 @@
-#Properties file for org.eclipse.papyrus.sysml.nattable.allocation
-Bundle-Vendor = Eclipse Modeling Project
+#Properties file for org.eclipse.papyrus.eastadl.nattable.allocation
+Bundle-Vendor = Eclipse Modeling Project
Bundle-Name = Eastadl FunctionAllocation Table (Incubation) \ No newline at end of file
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_SysML_Allocation_new.png b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_Eastadl_Allocation_new.png
index fc8ff255e1a..fc8ff255e1a 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_SysML_Allocation_new.png
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/icons/table_Eastadl_Allocation_new.png
Binary files differ
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/plugin.xml b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/plugin.xml
index ee16660e1e5..1d5f5df50bc 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/plugin.xml
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.allocation/plugin.xml
@@ -1,63 +1,63 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<?eclipse version="3.4"?>
-<plugin>
- <extension
- point="org.eclipse.ui.commands">
- <command
- categoryId="org.eclipse.papyrus.editor.category"
- description="Create a EastAdl FunctionAllocation NatTable Editor"
- id="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
- name="Create a new FunctionAllocation Table">
- </command>
- </extension>
- <extension
- point="org.eclipse.ui.commandImages">
- <image
- commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
- icon="icons/table_SysML_Allocation_new.png">
- </image>
- </extension>
- <extension
- point="org.eclipse.ui.handlers">
- <handler
- commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command">
- <activeWhen>
- <or>
- <with
- variable="activeEditorId">
- <equals
- value="org.eclipse.papyrus.infra.core.papyrusEditor">
- </equals>
- </with>
- </or>
- </activeWhen>
- <class
- class="org.eclipse.papyrus.infra.nattable.common.handlers.CreateNatTableEditorHandler">
- <parameter
- name="tableType"
- value="EAST-ADLFunctionAllocationTable">
- </parameter>
- </class>
- </handler>
- </extension>
- <extension
- point="org.eclipse.ui.menus">
- <menuContribution
- allPopups="false"
- locationURI="popup:org.eclipse.papyrus.infra.nattable.popupmenu.createnattable">
- <command
- commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
- style="push">
- </command>
- </menuContribution>
- <menuContribution
- allPopups="false"
- locationURI="menu:org.eclipse.papyrus.infra.nattable.menu.createnattable">
- <command
- commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
- style="push">
- </command>
- </menuContribution>
- </extension>
-
-</plugin>
+<?xml version="1.0" encoding="UTF-8"?>
+<?eclipse version="3.4"?>
+<plugin>
+ <extension
+ point="org.eclipse.ui.commands">
+ <command
+ categoryId="org.eclipse.papyrus.editor.category"
+ description="Create a EastAdl FunctionAllocation NatTable Editor"
+ id="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
+ name="Create a new FunctionAllocation Table">
+ </command>
+ </extension>
+ <extension
+ point="org.eclipse.ui.commandImages">
+ <image
+ commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
+ icon="icons/table_Eastadl_Allocation_new.png">
+ </image>
+ </extension>
+ <extension
+ point="org.eclipse.ui.handlers">
+ <handler
+ commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command">
+ <activeWhen>
+ <or>
+ <with
+ variable="activeEditorId">
+ <equals
+ value="org.eclipse.papyrus.infra.core.papyrusEditor">
+ </equals>
+ </with>
+ </or>
+ </activeWhen>
+ <class
+ class="org.eclipse.papyrus.infra.nattable.common.handlers.CreateNatTableEditorHandler">
+ <parameter
+ name="tableType"
+ value="EAST-ADLFunctionAllocationTable">
+ </parameter>
+ </class>
+ </handler>
+ </extension>
+ <extension
+ point="org.eclipse.ui.menus">
+ <menuContribution
+ allPopups="false"
+ locationURI="popup:org.eclipse.papyrus.infra.nattable.popupmenu.createnattable">
+ <command
+ commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
+ style="push">
+ </command>
+ </menuContribution>
+ <menuContribution
+ allPopups="false"
+ locationURI="menu:org.eclipse.papyrus.infra.nattable.menu.createnattable">
+ <command
+ commandId="org.eclipse.papyrus.eastadl.nattable.allocation.create.command"
+ style="push">
+ </command>
+ </menuContribution>
+ </extension>
+
+</plugin>
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.menu/OSGI-INF/l10n/bundle.properties b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.menu/OSGI-INF/l10n/bundle.properties
index 0e3374a8431..94e51153353 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.menu/OSGI-INF/l10n/bundle.properties
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.nattable.menu/OSGI-INF/l10n/bundle.properties
@@ -1,3 +1,3 @@
-#Properties file for org.eclipse.papyrus.sysml.nattable.menu
-Bundle-Vendor = Eclipse Modeling Project
-Bundle-Name = Menu for the creation of Sysml elements in the tabular editor (Incubation) \ No newline at end of file
+#Properties file for org.eclipse.papyrus.eastadl.nattable.menu
+Bundle-Vendor = Eclipse Modeling Project
+Bundle-Name = Menu for the creation of eastadl elements in the tabular editor (Incubation) \ No newline at end of file
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/elements/EastadlElementTypes.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/elements/EastadlElementTypes.java
index f1bc0e70518..ca80dbe5221 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/elements/EastadlElementTypes.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/elements/EastadlElementTypes.java
@@ -1,13 +1,13 @@
-package org.eclipse.papyrus.eastadl.service.types.elements;
-
-import org.eclipse.gmf.runtime.emf.type.core.AbstractElementTypeEnumerator;
-import org.eclipse.gmf.runtime.emf.type.core.IHintedType;
-
-public class EastadlElementTypes extends AbstractElementTypeEnumerator {
-
- /** Constant for SysML nature */
- public static final String SYSML_NATURE = "East-adl_Nature";
-
- /** IElementType for SysML Allocate */
- public static final IHintedType FUNCTION_ALLOCATE = (IHintedType) getElementType("org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionAllocation"); //$NON-NLS-1$
-}
+package org.eclipse.papyrus.eastadl.service.types.elements;
+
+import org.eclipse.gmf.runtime.emf.type.core.AbstractElementTypeEnumerator;
+import org.eclipse.gmf.runtime.emf.type.core.IHintedType;
+
+public class EastadlElementTypes extends AbstractElementTypeEnumerator {
+
+ /** Constant for EASTADL nature */
+ public static final String EASTADL_NATURE = "East-adl_Nature";
+
+ /** IElementType for EASTADL Allocate */
+ public static final IHintedType FUNCTION_ALLOCATE = (IHintedType) getElementType("org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionAllocation"); //$NON-NLS-1$
+}
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/menu/AbstractCreateEastadlChildMenu.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/menu/AbstractCreateEastadlChildMenu.java
index c3141aa0c8f..a999288ce45 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/menu/AbstractCreateEastadlChildMenu.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl.service.types/src/org/eclipse/papyrus/eastadl/service/types/menu/AbstractCreateEastadlChildMenu.java
@@ -1,17 +1,17 @@
-package org.eclipse.papyrus.eastadl.service.types.menu;
-
-import org.eclipse.papyrus.infra.ui.util.AbstractCreateMenuFromCommandCategory;
-
-public class AbstractCreateEastadlChildMenu extends AbstractCreateMenuFromCommandCategory {
-
- /** the cateogory of the command used to create SysML elements */
- public static final String SYSML_CREATION_COMMAND_CATEGORY = "org.eclipse.papyrus.eastadl.service.types.eastadlElementCreationCommands"; //$NON-NLS-1$
-
- /**
- * Constructor.
- *
- */
- public AbstractCreateEastadlChildMenu() {
- super(SYSML_CREATION_COMMAND_CATEGORY);
- }
-}
+package org.eclipse.papyrus.eastadl.service.types.menu;
+
+import org.eclipse.papyrus.infra.ui.util.AbstractCreateMenuFromCommandCategory;
+
+public class AbstractCreateEastadlChildMenu extends AbstractCreateMenuFromCommandCategory {
+
+ /** the cateogory of the command used to create EASTADL elements */
+ public static final String EASTADL_CREATION_COMMAND_CATEGORY = "org.eclipse.papyrus.eastadl.service.types.eastadlElementCreationCommands"; //$NON-NLS-1$
+
+ /**
+ * Constructor.
+ *
+ */
+ public AbstractCreateEastadlChildMenu() {
+ super(EASTADL_CREATION_COMMAND_CATEGORY);
+ }
+}
diff --git a/extraplugins/req/org.eclipse.papyrus.req.reqif/META-INF/MANIFEST.MF b/extraplugins/req/org.eclipse.papyrus.req.reqif/META-INF/MANIFEST.MF
index 2b0b12345d6..a242b2e2a38 100644
--- a/extraplugins/req/org.eclipse.papyrus.req.reqif/META-INF/MANIFEST.MF
+++ b/extraplugins/req/org.eclipse.papyrus.req.reqif/META-INF/MANIFEST.MF
@@ -24,7 +24,6 @@ Require-Bundle: org.eclipse.ui,
org.eclipse.papyrus.uml.extensionpoints,
org.eclipse.papyrus.uml.diagram.profile,
org.eclipse.papyrus.uml.profile,
- org.eclipse.papyrus.sysml.service.types;bundle-version="1.0.0",
org.eclipse.papyrus.infra.services.edit,
org.eclipse.papyrus.infra.gmfdiag.commands,
org.eclipse.rmf.reqif10.common,
diff --git a/extraplugins/req/org.eclipse.papyrus.req.reqif/src/org/eclipse/papyrus/req/reqif/integration/transformation/ReqIFImporterServiceEdit.java b/extraplugins/req/org.eclipse.papyrus.req.reqif/src/org/eclipse/papyrus/req/reqif/integration/transformation/ReqIFImporterServiceEdit.java
index 603d191061b..0e920c9e782 100644
--- a/extraplugins/req/org.eclipse.papyrus.req.reqif/src/org/eclipse/papyrus/req/reqif/integration/transformation/ReqIFImporterServiceEdit.java
+++ b/extraplugins/req/org.eclipse.papyrus.req.reqif/src/org/eclipse/papyrus/req/reqif/integration/transformation/ReqIFImporterServiceEdit.java
@@ -1,143 +1,142 @@
-/*****************************************************************************
- * Copyright (c) 2014 CEA LIST.
- *
- *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- * Patrick Tessier (CEA LIST) patrick.tessier@cea.fr - Initial API and implementation
- *
- *****************************************************************************/
-package org.eclipse.papyrus.req.reqif.integration.transformation;
-
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.GregorianCalendar;
-import java.util.HashMap;
-
-import org.eclipse.core.commands.ExecutionException;
-import org.eclipse.core.runtime.NullProgressMonitor;
-import org.eclipse.emf.common.command.Command;
-import org.eclipse.emf.transaction.TransactionalEditingDomain;
-import org.eclipse.gmf.runtime.common.core.command.ICommand;
-import org.eclipse.gmf.runtime.emf.type.core.requests.CreateElementRequest;
-import org.eclipse.papyrus.infra.services.edit.service.ElementEditServiceUtils;
-import org.eclipse.papyrus.infra.services.edit.service.IElementEditService;
-import org.eclipse.papyrus.req.reqif.integration.assistant.ChooseReqIFTypeDialog;
-import org.eclipse.papyrus.req.reqif.integration.command.DefineProfileCommand;
-import org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter;
-import org.eclipse.papyrus.sysml.service.types.element.SysMLElementTypes;
-import org.eclipse.papyrus.uml.service.types.element.UMLElementTypes;
-import org.eclipse.rmf.reqif10.ReqIF;
-import org.eclipse.rmf.reqif10.SpecType;
-import org.eclipse.swt.widgets.Shell;
-import org.eclipse.uml2.uml.Class;
-import org.eclipse.uml2.uml.Dependency;
-import org.eclipse.uml2.uml.Package;
-import org.eclipse.uml2.uml.Profile;
-
-/**
- * implementation of a ReqIFImport dependent of Papyrus.
- *
- */
-
-public class ReqIFImporterServiceEdit extends ReqIFImporter {
-
-
- /**
- *
- * Constructor.
- *
- * @param domain the domain to execute command
- * @param reqIFModel the reqIF model that is imported
- * @param UMLModel the UML model that contain imported elements
- */
- public ReqIFImporterServiceEdit(TransactionalEditingDomain domain, ReqIF reqIFModel, Package UMLModel) {
- super(domain, reqIFModel, UMLModel);
- }
-
- /**
- *
- * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#createRequirementClass(org.eclipse.uml2.uml.Element)
- *{@inheritDoc}
- */
- protected Class createClassWithRequirementName(org.eclipse.uml2.uml.Element owner) {
- IElementEditService provider = ElementEditServiceUtils.getCommandProvider(owner);
- if(provider == null) {
- return null;
- }
-
- ICommand createGMFCommand = provider.getEditCommand(new CreateElementRequest(domain, owner, UMLElementTypes.CLASS));
- if(createGMFCommand != null) {
- Command emfCommand = new org.eclipse.papyrus.commands.wrappers.GMFtoEMFCommandWrapper(createGMFCommand);
- domain.getCommandStack().execute(emfCommand);
- Class theClass= (Class)createGMFCommand.getCommandResult().getReturnValue();
- theClass.setName(theClass.getName().replaceAll("Class", "Requirement"));
- return theClass;
- }
- return null;
- }
-
- /**
- *
- * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#createDependency(org.eclipse.uml2.uml.Package)
- *{@inheritDoc}
- */
- protected Dependency createDependency(Package uMLModel) {
- IElementEditService provider = ElementEditServiceUtils.getCommandProvider(uMLModel);
- if(provider == null) {
- return null;
- }
-
- ICommand createGMFCommand = provider.getEditCommand(new CreateElementRequest(domain, uMLModel,org.eclipse.papyrus.uml.service.types.element.UMLElementTypes.DEPENDENCY));
- if(createGMFCommand != null) {
-
- Command emfCommand = new org.eclipse.papyrus.commands.wrappers.GMFtoEMFCommandWrapper(createGMFCommand);
- domain.getCommandStack().execute(emfCommand);
- return (Dependency)createGMFCommand.getCommandResult().getReturnValue();
- }
- return null;
- }
-
- /**
- *
- * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#selectReqIFType(java.util.Collection)
- *{@inheritDoc}
- *
- */
- protected HashMap<String, SpecType> selectReqIFType(Collection<SpecType> availableReqiFTypes) {
- HashMap<String, SpecType> selectedReqiFType= new HashMap<String, SpecType>();
- ChooseReqIFTypeDialog assistedDialog= new ChooseReqIFTypeDialog(new Shell(), availableReqiFTypes);
- assistedDialog.open();
- ArrayList<Object> result=assistedDialog.getSelectedElements();
- for(Object object : result) {
- if(object instanceof SpecType){
- selectedReqiFType.put(((SpecType)object).getLongName(), ((SpecType)object));
- }
- }
- return selectedReqiFType;
-
- }
-
- /**
- *
- * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#defineProfile(org.eclipse.uml2.uml.Profile)
- *
- * {@inheritDoc}
- */
- protected void defineProfile(Profile profile) {
- try {
- DefineProfileCommand defineProfileCmd= new DefineProfileCommand(domain, new org.eclipse.papyrus.uml.tools.profile.definition.PapyrusDefinitionAnnotation(new org.eclipse.papyrus.uml.tools.profile.definition.Version(1, 0, 0), "generated by Papyrus Req","", GregorianCalendar.getInstance().getTime().toString(), "Papyrus Req"), profile, true);
- defineProfileCmd.execute(new NullProgressMonitor(), null);
- profile.eResource().save(null);
- } catch (IOException e) {
- e.printStackTrace();
- } catch (ExecutionException e) {
- e.printStackTrace();
- }
- }
-}
+/*****************************************************************************
+ * Copyright (c) 2014 CEA LIST.
+ *
+ *
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Patrick Tessier (CEA LIST) patrick.tessier@cea.fr - Initial API and implementation
+ *
+ *****************************************************************************/
+package org.eclipse.papyrus.req.reqif.integration.transformation;
+
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.GregorianCalendar;
+import java.util.HashMap;
+
+import org.eclipse.core.commands.ExecutionException;
+import org.eclipse.core.runtime.NullProgressMonitor;
+import org.eclipse.emf.common.command.Command;
+import org.eclipse.emf.transaction.TransactionalEditingDomain;
+import org.eclipse.gmf.runtime.common.core.command.ICommand;
+import org.eclipse.gmf.runtime.emf.type.core.requests.CreateElementRequest;
+import org.eclipse.papyrus.infra.services.edit.service.ElementEditServiceUtils;
+import org.eclipse.papyrus.infra.services.edit.service.IElementEditService;
+import org.eclipse.papyrus.req.reqif.integration.assistant.ChooseReqIFTypeDialog;
+import org.eclipse.papyrus.req.reqif.integration.command.DefineProfileCommand;
+import org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter;
+import org.eclipse.papyrus.uml.service.types.element.UMLElementTypes;
+import org.eclipse.rmf.reqif10.ReqIF;
+import org.eclipse.rmf.reqif10.SpecType;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.uml2.uml.Class;
+import org.eclipse.uml2.uml.Dependency;
+import org.eclipse.uml2.uml.Package;
+import org.eclipse.uml2.uml.Profile;
+
+/**
+ * implementation of a ReqIFImport dependent of Papyrus.
+ *
+ */
+
+public class ReqIFImporterServiceEdit extends ReqIFImporter {
+
+
+ /**
+ *
+ * Constructor.
+ *
+ * @param domain the domain to execute command
+ * @param reqIFModel the reqIF model that is imported
+ * @param UMLModel the UML model that contain imported elements
+ */
+ public ReqIFImporterServiceEdit(TransactionalEditingDomain domain, ReqIF reqIFModel, Package UMLModel) {
+ super(domain, reqIFModel, UMLModel);
+ }
+
+ /**
+ *
+ * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#createRequirementClass(org.eclipse.uml2.uml.Element)
+ *{@inheritDoc}
+ */
+ protected Class createClassWithRequirementName(org.eclipse.uml2.uml.Element owner) {
+ IElementEditService provider = ElementEditServiceUtils.getCommandProvider(owner);
+ if(provider == null) {
+ return null;
+ }
+
+ ICommand createGMFCommand = provider.getEditCommand(new CreateElementRequest(domain, owner, UMLElementTypes.CLASS));
+ if(createGMFCommand != null) {
+ Command emfCommand = new org.eclipse.papyrus.commands.wrappers.GMFtoEMFCommandWrapper(createGMFCommand);
+ domain.getCommandStack().execute(emfCommand);
+ Class theClass= (Class)createGMFCommand.getCommandResult().getReturnValue();
+ theClass.setName(theClass.getName().replaceAll("Class", "Requirement"));
+ return theClass;
+ }
+ return null;
+ }
+
+ /**
+ *
+ * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#createDependency(org.eclipse.uml2.uml.Package)
+ *{@inheritDoc}
+ */
+ protected Dependency createDependency(Package uMLModel) {
+ IElementEditService provider = ElementEditServiceUtils.getCommandProvider(uMLModel);
+ if(provider == null) {
+ return null;
+ }
+
+ ICommand createGMFCommand = provider.getEditCommand(new CreateElementRequest(domain, uMLModel,org.eclipse.papyrus.uml.service.types.element.UMLElementTypes.DEPENDENCY));
+ if(createGMFCommand != null) {
+
+ Command emfCommand = new org.eclipse.papyrus.commands.wrappers.GMFtoEMFCommandWrapper(createGMFCommand);
+ domain.getCommandStack().execute(emfCommand);
+ return (Dependency)createGMFCommand.getCommandResult().getReturnValue();
+ }
+ return null;
+ }
+
+ /**
+ *
+ * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#selectReqIFType(java.util.Collection)
+ *{@inheritDoc}
+ *
+ */
+ protected HashMap<String, SpecType> selectReqIFType(Collection<SpecType> availableReqiFTypes) {
+ HashMap<String, SpecType> selectedReqiFType= new HashMap<String, SpecType>();
+ ChooseReqIFTypeDialog assistedDialog= new ChooseReqIFTypeDialog(new Shell(), availableReqiFTypes);
+ assistedDialog.open();
+ ArrayList<Object> result=assistedDialog.getSelectedElements();
+ for(Object object : result) {
+ if(object instanceof SpecType){
+ selectedReqiFType.put(((SpecType)object).getLongName(), ((SpecType)object));
+ }
+ }
+ return selectedReqiFType;
+
+ }
+
+ /**
+ *
+ * @see org.eclipse.papyrus.req.reqif.transformation.ReqIFImporter#defineProfile(org.eclipse.uml2.uml.Profile)
+ *
+ * {@inheritDoc}
+ */
+ protected void defineProfile(Profile profile) {
+ try {
+ DefineProfileCommand defineProfileCmd= new DefineProfileCommand(domain, new org.eclipse.papyrus.uml.tools.profile.definition.PapyrusDefinitionAnnotation(new org.eclipse.papyrus.uml.tools.profile.definition.Version(1, 0, 0), "generated by Papyrus Req","", GregorianCalendar.getInstance().getTime().toString(), "Papyrus Req"), profile, true);
+ defineProfileCmd.execute(new NullProgressMonitor(), null);
+ profile.eResource().save(null);
+ } catch (IOException e) {
+ e.printStackTrace();
+ } catch (ExecutionException e) {
+ e.printStackTrace();
+ }
+ }
+}
diff --git a/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlModelWizard.java b/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlModelWizard.java
index 5db94f3d54d..3e9901816e5 100644
--- a/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlModelWizard.java
+++ b/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlModelWizard.java
@@ -1,76 +1,73 @@
-/*****************************************************************************
- * Copyright (c) 2015 CEA LIST.
- *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- * Fadwa TMAR (CEA LIST) fadwa.tmar@cea.fr - Initial API and implementation
- *****************************************************************************/
-package org.eclipse.papyrus.soaml.diagram.ui;
-
-
-import org.eclipse.jface.viewers.IStructuredSelection;
-import org.eclipse.papyrus.soaml.diagram.common.commands.CreateSoamlModelCommand;
-import org.eclipse.papyrus.uml.diagram.wizards.CreateModelWizard;
-
-import org.eclipse.papyrus.uml.diagram.wizards.pages.SelectDiagramCategoryPage;
-import org.eclipse.ui.IWorkbench;
-
-public class NewSoamlModelWizard extends CreateModelWizard {
-
- /**
- * @see org.eclipse.papyrus.wizards.CreateModelWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
- *
- * @param workbench
- * @param selection
- */
-
- @Override
- public void init(IWorkbench workbench, IStructuredSelection selection) {
- super.init(workbench, selection);
- setWindowTitle("New SoaML Model");
- }
-
- /**
- * Instantiates a new new Proteus model wizard.
- */
- public NewSoamlModelWizard() {
- super();
-
- }
-
-
-
- @Override
- public String getModelKindName() {
- // TODO Auto-generated method stub
-
- return "SoaML Model";
- }
-
- @Override
- protected String[] getDiagramCategoryIds() {
- return new String[]{ CreateSoamlModelCommand.COMMAND_ID };
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected SelectDiagramCategoryPage createSelectDiagramCategoryPage() {
- // here SoaML is the only available category
- return null;
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected void saveDiagramCategorySettings() {
- // here SoaML is the only available category
- }
-
-}
+/*****************************************************************************
+ * Copyright (c) 2015 CEA LIST.
+ *
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Fadwa TMAR (CEA LIST) fadwa.tmar@cea.fr - Initial API and implementation
+ *****************************************************************************/
+package org.eclipse.papyrus.soaml.diagram.ui;
+
+
+import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.papyrus.soaml.diagram.common.commands.CreateSoamlModelCommand;
+import org.eclipse.papyrus.uml.diagram.wizards.CreateModelWizard;
+
+import org.eclipse.papyrus.uml.diagram.wizards.pages.SelectDiagramCategoryPage;
+import org.eclipse.ui.IWorkbench;
+
+public class NewSoamlModelWizard extends CreateModelWizard {
+
+ /**
+ * @see org.eclipse.papyrus.wizards.CreateModelWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
+ *
+ * @param workbench
+ * @param selection
+ */
+
+ @Override
+ public void init(IWorkbench workbench, IStructuredSelection selection) {
+ super.init(workbench, selection);
+ setWindowTitle("New SoaML Model");
+ }
+
+ /**
+ * Instantiates a new new Proteus model wizard.
+ */
+ public NewSoamlModelWizard() {
+ super();
+ }
+
+
+
+ @Override
+ public String getModelKindName() {
+ return "SoaML Model"; //$NON-NLS-1$
+ }
+
+ @Override
+ protected String[] getDiagramCategoryIds() {
+ return new String[]{ CreateSoamlModelCommand.COMMAND_ID };
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected SelectDiagramCategoryPage createSelectDiagramCategoryPage() {
+ // here SoaML is the only available category
+ return null;
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected void saveDiagramCategorySettings() {
+ // here SoaML is the only available category
+ }
+
+}
diff --git a/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlProjectWizard.java b/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlProjectWizard.java
index 5f983ff6111..859ecfd0b51 100644
--- a/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlProjectWizard.java
+++ b/extraplugins/soaml/org.eclipse.papyrus.soaml.diagram.ui/src/org/eclipse/papyrus/soaml/diagram/ui/NewSoamlProjectWizard.java
@@ -1,73 +1,71 @@
-/*****************************************************************************
- * Copyright (c) 2015 CEA LIST.
- *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- * Fadwa TMAR (CEA LIST) fadwa.tmar@cea.fr - Initial API and implementation
- *****************************************************************************/
-package org.eclipse.papyrus.soaml.diagram.ui;
-
-import org.eclipse.jface.viewers.IStructuredSelection;
-import org.eclipse.papyrus.soaml.diagram.common.commands.CreateSoamlModelCommand;
-import org.eclipse.papyrus.uml.diagram.wizards.NewPapyrusProjectWizard;
-import org.eclipse.papyrus.uml.diagram.wizards.pages.SelectDiagramCategoryPage;
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.dialogs.WizardNewProjectCreationPage;
-
-public class NewSoamlProjectWizard extends NewPapyrusProjectWizard {
-
- /**
- * @see org.eclipse.papyrus.wizards.NewPapyrusProjectWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
- *
- * @param workbench
- * @param selection
- */
- @Override
- public void init(IWorkbench workbench, IStructuredSelection selection) {
- super.init(workbench, selection);
- setWindowTitle("New SoaML Project");
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected WizardNewProjectCreationPage createNewProjectCreationPage() {
- WizardNewProjectCreationPage newProjectPage = super.createNewProjectCreationPage();
- newProjectPage.setTitle("Papyrus SoaML Project");
- newProjectPage.setDescription("Create a New Papyrus SoaML Project");
- return newProjectPage;
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected SelectDiagramCategoryPage createSelectDiagramCategoryPage() {
- //here SysML is the only available category
- return null;
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected void saveDiagramCategorySettings() {
- //do nothing
- //here SysML is the only available category
- }
-
- /**
- * {@inheritDoc}
- */
- @Override
- protected String[] getDiagramCategoryIds() {
- return new String[]{ CreateSoamlModelCommand.COMMAND_ID };
- }
-
-
-}
+/*****************************************************************************
+ * Copyright (c) 2015 CEA LIST.
+ *
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Fadwa TMAR (CEA LIST) fadwa.tmar@cea.fr - Initial API and implementation
+ *****************************************************************************/
+package org.eclipse.papyrus.soaml.diagram.ui;
+
+import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.papyrus.soaml.diagram.common.commands.CreateSoamlModelCommand;
+import org.eclipse.papyrus.uml.diagram.wizards.NewPapyrusProjectWizard;
+import org.eclipse.papyrus.uml.diagram.wizards.pages.SelectDiagramCategoryPage;
+import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.dialogs.WizardNewProjectCreationPage;
+
+public class NewSoamlProjectWizard extends NewPapyrusProjectWizard {
+
+ /**
+ * @see org.eclipse.papyrus.wizards.NewPapyrusProjectWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
+ *
+ * @param workbench
+ * @param selection
+ */
+ @Override
+ public void init(IWorkbench workbench, IStructuredSelection selection) {
+ super.init(workbench, selection);
+ setWindowTitle("New SoaML Project");
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected WizardNewProjectCreationPage createNewProjectCreationPage() {
+ WizardNewProjectCreationPage newProjectPage = super.createNewProjectCreationPage();
+ newProjectPage.setTitle("Papyrus SoaML Project");
+ newProjectPage.setDescription("Create a New Papyrus SoaML Project");
+ return newProjectPage;
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected SelectDiagramCategoryPage createSelectDiagramCategoryPage() {
+ return null;
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected void saveDiagramCategorySettings() {
+ //do nothing
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ @Override
+ protected String[] getDiagramCategoryIds() {
+ return new String[]{ CreateSoamlModelCommand.COMMAND_ID };
+ }
+
+
+}

Back to the top
diff --git a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/CreateEFFBModelCommand.java b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/CreateEFFBModelCommand.java
index 1b6a6ff186c..4d9056ae6d5 100644
--- a/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/CreateEFFBModelCommand.java
+++ b/extraplugins/EFFBD/org.eclipse.papyrus.effbd/src/org/eclipse/papyrus/effbd/command/CreateEFFBModelCommand.java
@@ -48,10 +48,10 @@ public class CreateEFFBModelCommand extends ModelCreationCommandBase {
super.initializeModel(owner);
((org.eclipse.uml2.uml.Package) owner).setName(getModelName());
- // Retrieve SysML profile and apply with Sub-profile
- Profile sysml = (Profile) PackageUtil.loadPackage(URI.createURI(PROFILE_PATH), owner.eResource().getResourceSet());
- if (sysml != null) {
- PackageUtil.applyProfile(((org.eclipse.uml2.uml.Package) owner), sysml, true);
+ // Retrieve EFFB profile and apply with Sub-profile
+ Profile effb = (Profile) PackageUtil.loadPackage(URI.createURI(PROFILE_PATH), owner.eResource().getResourceSet());
+ if (effb != null) {
+ PackageUtil.applyProfile(((org.eclipse.uml2.uml.Package) owner), effb, true);
}
}